var searchData=
[
  ['s1',['s1',['../global__variables_8cpp.html#a24573a2e279db4db9228d18dfbf27eae',1,'global_variables.cpp']]],
  ['s2',['s2',['../global__variables_8cpp.html#a8163feae57063e5c0bb2e640ff4e8c7a',1,'global_variables.cpp']]],
  ['scalar_5fchar',['scalar_char',['../structviennacl_1_1scheduler_1_1lhs__rhs__element.html#a999fe044471c337ab83c21c957a4d148',1,'viennacl::scheduler::lhs_rhs_element']]],
  ['scalar_5fdouble',['scalar_double',['../structviennacl_1_1scheduler_1_1lhs__rhs__element.html#acba0a3c3e029a3e0134a2828d729e61e',1,'viennacl::scheduler::lhs_rhs_element']]],
  ['scalar_5ffloat',['scalar_float',['../structviennacl_1_1scheduler_1_1lhs__rhs__element.html#a35fe2d6c0ef69f04ad2c94d7b10c7cdd',1,'viennacl::scheduler::lhs_rhs_element']]],
  ['scalar_5fint',['scalar_int',['../structviennacl_1_1scheduler_1_1lhs__rhs__element.html#af04a7d16cd1145bd1620eb8f8318c401',1,'viennacl::scheduler::lhs_rhs_element']]],
  ['scalar_5flong',['scalar_long',['../structviennacl_1_1scheduler_1_1lhs__rhs__element.html#af320004b345267a0cbc444fbe700b6a7',1,'viennacl::scheduler::lhs_rhs_element']]],
  ['scalar_5fshort',['scalar_short',['../structviennacl_1_1scheduler_1_1lhs__rhs__element.html#a9aeb475e7db46c9be9d85c8c9d309e8c',1,'viennacl::scheduler::lhs_rhs_element']]],
  ['scalar_5fuchar',['scalar_uchar',['../structviennacl_1_1scheduler_1_1lhs__rhs__element.html#a5276e464de5b699b3ce67feb9569567d',1,'viennacl::scheduler::lhs_rhs_element']]],
  ['scalar_5fuint',['scalar_uint',['../structviennacl_1_1scheduler_1_1lhs__rhs__element.html#aa15f7aab442438f3c7ff0231565e84eb',1,'viennacl::scheduler::lhs_rhs_element']]],
  ['scalar_5fulong',['scalar_ulong',['../structviennacl_1_1scheduler_1_1lhs__rhs__element.html#a6b35995ccb55bb06d4dd4ec3083396c2',1,'viennacl::scheduler::lhs_rhs_element']]],
  ['scalar_5fushort',['scalar_ushort',['../structviennacl_1_1scheduler_1_1lhs__rhs__element.html#adb110a17e60fd71f4e276104e5343b6b',1,'viennacl::scheduler::lhs_rhs_element']]],
  ['scalartype_5f',['scalartype_',['../classviennacl_1_1device__specific_1_1mapped__object.html#a71b8b927545d109d7a4f8c5726312fe8',1,'viennacl::device_specific::mapped_object']]],
  ['simd_5fwidth',['simd_width',['../structviennacl_1_1device__specific_1_1template__base_1_1parameters__type.html#af859aa51f8a2c20e654f63fdb34bb5b6',1,'viennacl::device_specific::template_base::parameters_type']]],
  ['size',['size',['../structviennacl_1_1ocl_1_1packed__cl__uint.html#a5f4dcdfd54664fb7859b27f3dec641c0',1,'viennacl::ocl::packed_cl_uint::size()'],['../struct_vienna_c_l_vector__impl.html#a2102cfe143f959a93374f4c1632f3b15',1,'ViennaCLVector_impl::size()']]],
  ['size1',['size1',['../struct_vienna_c_l_matrix__impl.html#a83761810e0c5f91ea10ef3a4167b78d7',1,'ViennaCLMatrix_impl']]],
  ['size1_5f',['size1_',['../classviennacl_1_1implicit__matrix__base.html#af45a73be66586ba3d7e64ea917e0a072',1,'viennacl::implicit_matrix_base']]],
  ['size2',['size2',['../struct_vienna_c_l_matrix__impl.html#ac2184140bcb059f7521857a6a5ef4362',1,'ViennaCLMatrix_impl']]],
  ['size2_5f',['size2_',['../classviennacl_1_1implicit__matrix__base.html#a6873916ea820179b0bb9c6cafa8e6b00',1,'viennacl::implicit_matrix_base']]],
  ['size_5f',['size_',['../classviennacl_1_1implicit__vector__base.html#aec8627d9a9f2b395bef3e0e39d0e71e8',1,'viennacl::implicit_vector_base::size_()'],['../structviennacl_1_1linalg_1_1detail_1_1ilut__sparse__vector.html#a596273b4c650b973e801e4f182b78ba7',1,'viennacl::linalg::detail::ilut_sparse_vector::size_()']]],
  ['start',['start',['../structviennacl_1_1ocl_1_1packed__cl__uint.html#a7991987e7676fabb8d1cbc54eaa0ba01',1,'viennacl::ocl::packed_cl_uint']]],
  ['start1',['start1',['../struct_vienna_c_l_matrix__impl.html#a56404bb5c6aaf0b64c53c89b2f6bc26a',1,'ViennaCLMatrix_impl']]],
  ['start2',['start2',['../struct_vienna_c_l_matrix__impl.html#ab7815c208b9260ca0097909c1892fd0f',1,'ViennaCLMatrix_impl']]],
  ['start_5f',['start_',['../classviennacl_1_1const__vector__iterator.html#aaff6b3b9edca90b6fac60fef55332b77',1,'viennacl::const_vector_iterator']]],
  ['statement',['statement',['../structviennacl_1_1device__specific_1_1mapped__object_1_1node__info.html#a5a38c1848cc1f189b2604edfa1755307',1,'viennacl::device_specific::mapped_object::node_info']]],
  ['std_5fa',['std_a',['../structviennacl_1_1linalg_1_1detail_1_1_input_data.html#a2b177029d0e953d92c03879d9a222db7',1,'viennacl::linalg::detail::InputData']]],
  ['std_5fb',['std_b',['../structviennacl_1_1linalg_1_1detail_1_1_input_data.html#a4b0a695a3baaf7c5253c1fc2c66b8780',1,'viennacl::linalg::detail::InputData']]],
  ['std_5feigenvalues',['std_eigenvalues',['../structviennacl_1_1linalg_1_1detail_1_1_result_data_small.html#aeba7abab2c64e83f40e4bf2d21348e9b',1,'viennacl::linalg::detail::ResultDataSmall::std_eigenvalues()'],['../structviennacl_1_1linalg_1_1detail_1_1_result_data_large.html#aab48d1f3f1fc63892adf79921805370f',1,'viennacl::linalg::detail::ResultDataLarge::std_eigenvalues()']]],
  ['step',['step',['../least-squares_8cpp.html#a3bd576e398e7f02a27a19950bb8530ad',1,'least-squares.cpp']]],
  ['stride',['stride',['../structviennacl_1_1ocl_1_1packed__cl__uint.html#a457e1f554ae439501613c843b6dad189',1,'viennacl::ocl::packed_cl_uint']]],
  ['stride1',['stride1',['../struct_vienna_c_l_matrix__impl.html#a1a2591ff60fda8cb4e932ee8e4220e37',1,'ViennaCLMatrix_impl']]],
  ['stride2',['stride2',['../struct_vienna_c_l_matrix__impl.html#a1bb3e3df3fe8b7befe40d30780779cb3',1,'ViennaCLMatrix_impl']]],
  ['stride_5f',['stride_',['../classviennacl_1_1const__vector__iterator.html#abda30c30684ac0ee23edebf6538a483f',1,'viennacl::const_vector_iterator']]],
  ['subtype',['subtype',['../structviennacl_1_1scheduler_1_1lhs__rhs__element.html#adfd75a96c83f174e2460d48b99578bfb',1,'viennacl::scheduler::lhs_rhs_element']]],
  ['svd_5fbidiag_5fpack_5fkernel',['SVD_BIDIAG_PACK_KERNEL',['../namespaceviennacl_1_1linalg_1_1opencl.html#a6c692160febc1bf0c8c1b3f14609843b',1,'viennacl::linalg::opencl']]],
  ['svd_5fcopy_5fcol_5fkernel',['SVD_COPY_COL_KERNEL',['../namespaceviennacl_1_1linalg_1_1opencl.html#a83f95bb0dba31593bfdea7d48825ef45',1,'viennacl::linalg::opencl']]],
  ['svd_5fcopy_5frow_5fkernel',['SVD_COPY_ROW_KERNEL',['../namespaceviennacl_1_1linalg_1_1opencl.html#adf9d9e0232c7731006e942e6f1eb787c',1,'viennacl::linalg::opencl']]],
  ['svd_5ffinal_5fiter_5fupdate_5fkernel',['SVD_FINAL_ITER_UPDATE_KERNEL',['../namespaceviennacl_1_1linalg.html#a8477d884683dafc7e6ca04f2e02a1d1f',1,'viennacl::linalg']]],
  ['svd_5fgivens_5fnext_5fkernel',['SVD_GIVENS_NEXT_KERNEL',['../namespaceviennacl_1_1linalg_1_1opencl.html#ae14982b121ba058e0cc0569b93f80646',1,'viennacl::linalg::opencl']]],
  ['svd_5fgivens_5fprev_5fkernel',['SVD_GIVENS_PREV_KERNEL',['../namespaceviennacl_1_1linalg.html#a15bedacb51ec9b425baf52ee7f68bdba',1,'viennacl::linalg']]],
  ['svd_5fhouseholder_5fupdate_5fa_5fleft_5fkernel',['SVD_HOUSEHOLDER_UPDATE_A_LEFT_KERNEL',['../namespaceviennacl_1_1linalg_1_1opencl.html#a86b4bd11f0b1f0b701afa9448cbb865f',1,'viennacl::linalg::opencl::SVD_HOUSEHOLDER_UPDATE_A_LEFT_KERNEL()'],['../namespaceviennacl_1_1linalg.html#a8e62fa452895c889f7bad9700300994d',1,'viennacl::linalg::SVD_HOUSEHOLDER_UPDATE_A_LEFT_KERNEL()']]],
  ['svd_5fhouseholder_5fupdate_5fa_5fright_5fkernel',['SVD_HOUSEHOLDER_UPDATE_A_RIGHT_KERNEL',['../namespaceviennacl_1_1linalg_1_1opencl.html#a24049445243113b8aff433e4dd6d3c01',1,'viennacl::linalg::opencl::SVD_HOUSEHOLDER_UPDATE_A_RIGHT_KERNEL()'],['../namespaceviennacl_1_1linalg.html#ace85ea4095e9e7404b6f77b767ac000f',1,'viennacl::linalg::SVD_HOUSEHOLDER_UPDATE_A_RIGHT_KERNEL()']]],
  ['svd_5fhouseholder_5fupdate_5fql_5fkernel',['SVD_HOUSEHOLDER_UPDATE_QL_KERNEL',['../namespaceviennacl_1_1linalg_1_1opencl.html#a656519064a982e5904b5a66b5e9c2785',1,'viennacl::linalg::opencl::SVD_HOUSEHOLDER_UPDATE_QL_KERNEL()'],['../namespaceviennacl_1_1linalg.html#a04a5ce1f7230502c9d1ee87dcc24c8b4',1,'viennacl::linalg::SVD_HOUSEHOLDER_UPDATE_QL_KERNEL()']]],
  ['svd_5fhouseholder_5fupdate_5fqr_5fkernel',['SVD_HOUSEHOLDER_UPDATE_QR_KERNEL',['../namespaceviennacl_1_1linalg.html#a5b5cb81b46208cae772a5e0813f02517',1,'viennacl::linalg']]],
  ['svd_5finverse_5fsigns_5fkernel',['SVD_INVERSE_SIGNS_KERNEL',['../namespaceviennacl_1_1linalg.html#a05717ddd22894376e780b075d59616ed',1,'viennacl::linalg']]],
  ['svd_5fmatrix_5ftranspose_5fkernel',['SVD_MATRIX_TRANSPOSE_KERNEL',['../namespaceviennacl_1_1linalg.html#a349e6e78f95ef631a5f2736158766739',1,'viennacl::linalg']]],
  ['svd_5fupdate_5fqr_5fcolumn_5fkernel',['SVD_UPDATE_QR_COLUMN_KERNEL',['../namespaceviennacl_1_1linalg.html#a3a439370108ddfa59c2fcb4136b13c8d',1,'viennacl::linalg']]]
];
